@@ -1,7 +1,7 @@
 /* LICENSE BEGIN
     This file is part of the SixtyFPS Project -- https://sixtyfps.io
-    Copyright (c) 2020 Olivier Goffart <olivier.goffart@sixtyfps.io>
-    Copyright (c) 2020 Simon Hausmann <simon.hausmann@sixtyfps.io>
+    Copyright (c) 2021 Olivier Goffart <olivier.goffart@sixtyfps.io>
+    Copyright (c) 2021 Simon Hausmann <simon.hausmann@sixtyfps.io>
 
     SPDX-License-Identifier: GPL-3.0-only
     This file is also available under commercial licensing terms.
@@ -12,7 +12,9 @@ use std::path::Path;
 
 use super::util::lookup_current_element_type;
 use super::DocumentCache;
-use lsp_types::{CompletionCapability, CompletionItem, CompletionItemKind, InsertTextFormat};
+use lsp_types::{
+    CompletionClientCapabilities, CompletionItem, CompletionItemKind, InsertTextFormat,
+};
 use sixtyfps_compilerlib::diagnostics::Spanned;
 use sixtyfps_compilerlib::expression_tree::Expression;
 use sixtyfps_compilerlib::langtype::Type;
@@ -23,7 +25,7 @@ pub(crate) fn completion_at(
     document_cache: &DocumentCache,
     token: SyntaxToken,
     offset: u32,
-    client_caps: Option<&CompletionCapability>,
+    client_caps: Option<&CompletionClientCapabilities>,
 ) -> Option<Vec<CompletionItem>> {
     let node = token.parent();
 
@@ -110,7 +112,7 @@ pub(crate) fn completion_at(
         SyntaxKind::Type | SyntaxKind::ArrayType | SyntaxKind::ObjectType | SyntaxKind::ReturnType
     ) {
         return resolve_type_scope(token, document_cache);
-    } else if let Some(_) = syntax_nodes::PropertyDeclaration::new(node.clone()) {
+    } else if syntax_nodes::PropertyDeclaration::new(node.clone()).is_some() {
         if token.kind() == SyntaxKind::LAngle {
             return resolve_type_scope(token, document_cache);
         }
@@ -148,6 +150,8 @@ pub(crate) fn completion_at(
                 return Some(
                     tr.all_types()
                         .into_iter()
+                        // manually filter deprecated or undocumented cases
+                        .filter(|(k, _)| k != "Clip")
                         .filter_map(|(k, t)| {
                             match t {
                                 Type::Component(c) if !c.is_global() => (),
@@ -178,8 +182,7 @@ pub(crate) fn completion_at(
                     let global = sixtyfps_compilerlib::lookup::global_lookup();
                     let mut expr_it = global.lookup(ctx, &first)?.expression;
                     let mut has_dot = false;
-                    loop {
-                        let t = if let Some(t) = it.next() { t } else { break };
+                    for t in it {
                         has_dot |= t.kind() == SyntaxKind::Dot;
                         if t.token == token.token {
                             break;
@@ -204,13 +207,13 @@ pub(crate) fn completion_at(
             _ => (),
         }
     }
-    return None;
+    None
 }
 
 fn with_insert_text(
     mut c: CompletionItem,
     ins_text: &str,
-    client_caps: Option<&CompletionCapability>,
+    client_caps: Option<&CompletionClientCapabilities>,
 ) -> CompletionItem {
     if client_caps
         .and_then(|caps| caps.completion_item.as_ref())
@@ -240,7 +243,7 @@ fn resolve_element_scope(
             .into_iter()
             .map(|(k, t)| {
                 let mut c = CompletionItem::new_simple(k, t.to_string());
-                c.kind = Some(if matches!(t, Type::Callback { .. }) {
+                c.kind = Some(if matches!(t, Type::InferredCallback | Type::Callback { .. }) {
                     CompletionItemKind::Method
                 } else {
                     CompletionItemKind::Property
@@ -271,7 +274,7 @@ fn resolve_element_scope(
                         return None;
                     }
                     let mut c = CompletionItem::new_simple(k.into(), t.to_string());
-                    c.kind = Some(if matches!(t, Type::Callback { .. }) {
+                    c.kind = Some(if matches!(t, Type::InferredCallback | Type::Callback { .. }) {
                         CompletionItemKind::Method
                     } else {
                         CompletionItemKind::Property
@@ -296,7 +299,7 @@ fn resolve_element_scope(
 fn resolve_expression_scope(lookup_context: &LookupCtx) -> Option<Vec<CompletionItem>> {
     let mut r = Vec::new();
     let global = sixtyfps_compilerlib::lookup::global_lookup();
-    global.for_each_entry(&lookup_context, &mut |str, expr| -> Option<()> {
+    global.for_each_entry(lookup_context, &mut |str, expr| -> Option<()> {
         r.push(completion_item_from_expression(str, expr));
         None
     });
@@ -355,7 +358,7 @@ fn complete_path_in_string(base: &Path, text: &str, offset: u32) -> Option<Vec<C
     if offset as usize > text.len() || offset == 0 {
         return None;
     }
-    let mut text = text.strip_prefix("\"")?;
+    let mut text = text.strip_prefix('\"')?;
     text = &text[..(offset - 1) as usize];
     let path = if let Some(last_slash) = text.rfind('/') {
         base.parent()?.join(Path::new(&text[..last_slash]))
