@@ -12,6 +12,7 @@ mod completion;
 mod goto;
 mod lsp_ext;
 mod preview;
+mod semantic_tokens;
 mod util;
 
 use std::collections::HashMap;
@@ -21,15 +22,15 @@ use lsp_server::{Connection, Message, Request, RequestId, Response};
 use lsp_types::notification::{DidChangeTextDocument, DidOpenTextDocument, Notification};
 use lsp_types::request::{
     CodeActionRequest, CodeLensRequest, ColorPresentationRequest, Completion, DocumentColor,
-    DocumentSymbolRequest, ExecuteCommand, GotoDefinition, HoverRequest,
+    DocumentSymbolRequest, ExecuteCommand, GotoDefinition, HoverRequest, SemanticTokensFullRequest,
 };
 use lsp_types::{
     CodeActionOrCommand, CodeActionProviderCapability, CodeLens, CodeLensOptions, Color,
     ColorInformation, ColorPresentation, Command, CompletionOptions, DidChangeTextDocumentParams,
     DidOpenTextDocumentParams, DocumentSymbolResponse, ExecuteCommandOptions, Hover,
     InitializeParams, Location, OneOf, Position, PublishDiagnosticsParams, Range,
-    ServerCapabilities, SymbolInformation, TextDocumentSyncCapability, Url,
-    WorkDoneProgressOptions,
+    SemanticTokensFullOptions, SemanticTokensLegend, SemanticTokensOptions, ServerCapabilities,
+    SymbolInformation, TextDocumentSyncCapability, Url, WorkDoneProgressOptions,
 };
 use sixtyfps_compilerlib::diagnostics::BuildDiagnostics;
 use sixtyfps_compilerlib::langtype::Type;
@@ -163,6 +164,17 @@ fn run_lsp_server() -> Result<(), Error> {
         document_symbol_provider: Some(OneOf::Left(true)),
         color_provider: Some(true.into()),
         code_lens_provider: Some(CodeLensOptions { resolve_provider: Some(true) }),
+        semantic_tokens_provider: Some(
+            SemanticTokensOptions {
+                legend: SemanticTokensLegend {
+                    token_types: semantic_tokens::LEGEND_TYPES.iter().cloned().collect(),
+                    token_modifiers: semantic_tokens::LEGEND_MODS.iter().cloned().collect(),
+                },
+                full: Some(SemanticTokensFullOptions::Bool(true)),
+                ..Default::default()
+            }
+            .into(),
+        ),
         ..ServerCapabilities::default()
     };
     let server_capabilities = serde_json::to_value(&capabilities).unwrap();
@@ -293,6 +305,9 @@ fn handle_request(
     } else if let Some((id, params)) = cast::<CodeLensRequest>(&mut req) {
         let result = get_code_lenses(document_cache, &params.text_document);
         connection.sender.send(Message::Response(Response::new_ok(id, result)))?;
+    } else if let Some((id, params)) = cast::<SemanticTokensFullRequest>(&mut req) {
+        let result = semantic_tokens::get_semantic_tokens(document_cache, &params.text_document);
+        connection.sender.send(Message::Response(Response::new_ok(id, result)))?;
     };
     Ok(())
 }
