@@ -1,7 +1,7 @@
 /* LICENSE BEGIN
     This file is part of the SixtyFPS Project -- https://sixtyfps.io
-    Copyright (c) 2020 Olivier Goffart <olivier.goffart@sixtyfps.io>
-    Copyright (c) 2020 Simon Hausmann <simon.hausmann@sixtyfps.io>
+    Copyright (c) 2021 Olivier Goffart <olivier.goffart@sixtyfps.io>
+    Copyright (c) 2021 Simon Hausmann <simon.hausmann@sixtyfps.io>
 
     SPDX-License-Identifier: GPL-3.0-only
     This file is also available under commercial licensing terms.
@@ -106,7 +106,7 @@ fn lookup_expression_context(mut n: SyntaxNode) -> Option<(syntax_nodes::Element
             let prop_name =
                 sixtyfps_compilerlib::parser::identifier_text(&decl.DeclaredIdentifier())?;
             let element = syntax_nodes::Element::new(n.parent()?)?;
-            break (element, prop_name.to_string());
+            break (element, prop_name);
         }
         match n.kind() {
             SyntaxKind::Binding
@@ -115,7 +115,7 @@ fn lookup_expression_context(mut n: SyntaxNode) -> Option<(syntax_nodes::Element
             | SyntaxKind::CallbackConnection => {
                 let prop_name = sixtyfps_compilerlib::parser::identifier_text(&n)?;
                 let element = syntax_nodes::Element::new(n.parent()?)?;
-                break (element, prop_name.to_string());
+                break (element, prop_name);
             }
             SyntaxKind::ConditionalElement | SyntaxKind::RepeatedElement => {
                 let element = syntax_nodes::Element::new(n.parent()?)?;
